@@ -69,6 +69,7 @@ struct _EvViewAccessiblePrivate {
 };
 
 G_DEFINE_TYPE_WITH_CODE (EvViewAccessible, ev_view_accessible, GTK_TYPE_CONTAINER_ACCESSIBLE,
+			 G_ADD_PRIVATE (EvViewAccessible)
 			 G_IMPLEMENT_INTERFACE (ATK_TYPE_ACTION, ev_view_accessible_action_iface_init)
 			 G_IMPLEMENT_INTERFACE (ATK_TYPE_DOCUMENT, ev_view_accessible_document_iface_init)
 	)
@@ -175,14 +176,12 @@ ev_view_accessible_class_init (EvViewAccessibleClass *klass)
 	atk_class->initialize = ev_view_accessible_initialize;
 	atk_class->get_n_children = ev_view_accessible_get_n_children;
 	atk_class->ref_child = ev_view_accessible_ref_child;
-
-	g_type_class_add_private (klass, sizeof (EvViewAccessiblePrivate));
 }
 
 static void
 ev_view_accessible_init (EvViewAccessible *accessible)
 {
-	accessible->priv = G_TYPE_INSTANCE_GET_PRIVATE (accessible, EV_TYPE_VIEW_ACCESSIBLE, EvViewAccessiblePrivate);
+	accessible->priv = ev_view_accessible_get_instance_private (accessible);
 }
 
 #if ATK_CHECK_VERSION (2, 11, 3)
